Module output

Module output 

This module specifies the output format of an ft test case To add an output format, simply implement the FtOutput trait. This is what is done by YmlOutput and JsonOutput for example

Structs

Output
Output structure, contains what was expected and what has been output by the command

Traits

FtOutput